@@ -80,7 +80,7 @@ class UR3Arm(robot_arms.RobotArm):
 
     @tool_offset.setter
     def tool_offset(self, value: Location):
-        self.robot.set_tcp(*value.position, *value.orientation)
+        self.robot.set_tcp([*value.position, *value.orientation])
 
     @property
     def tool_mass(self) -> float:
